@@ -1,14 +1,14 @@
 package Crypt::Passphrase::PassphraseHash;
-$Crypt::Passphrase::PassphraseHash::VERSION = '0.006';
+$Crypt::Passphrase::PassphraseHash::VERSION = '0.007';
 use strict;
 use warnings;
 
 sub new {
-	my ($class, $crypt_passphrase, $hash) = @_;
+	my ($class, $validator, $raw_hash) = @_;
 
 	return bless {
-		validator => $crypt_passphrase,
-		raw_hash  => $hash,
+		validator => $validator,
+		raw_hash  => $raw_hash,
 	}, $class;
 }
 
@@ -41,17 +41,17 @@ Crypt::Passphrase::PassphraseHash
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
-This class can be useful for plugging C<Crypt::Passphrase> into some frameworks (e.g. ORMs).
+This class can be useful for plugging C<Crypt::Passphrase> into some frameworks (e.g. ORMs) that require a singular object to contain everything you need to match passwords against. Effectively it's little more or less than currying the C<$hash> parameter to C<verify_password> and C<needs_rehash>.
 
 =head1 METHODS
 
-=head2 new($crypt_passphrase, $hash)
+=head2 new($crypt_passphrase, $raw_hash)
 
-This takes a Crypt::Passphrase object, and a hash string.
+This takes a C<Crypt::Passphrase> object, and a hash string. You probably want to use the C<curry_with_hash> or C<curry_with_password> methods on C<Crypt::Passphrase> instead of calling this directly.
 
 =head2 verify_password($password)
 
@@ -63,7 +63,15 @@ Check if the hash needs to be rehashed.
 
 =head2 raw_hash()
 
-This returns the hash of this object as a string.
+This returns the hash contained in this object as a string.
+
+=head1 SEE ALSO
+
+=over 4
+
+=item * L<DBIx::Class::CryptColumn|DBIx::Class::CryptColumn>
+
+=back
 
 =head1 AUTHOR
 
